pub struct CommandInfo {
pub name: Option<String>,
pub description: Option<String>,
/* private fields */
}Expand description
Metadata for a supported command in the Debug protocol.
Fields
name: Option<String>The name of the command.
description: Option<String>A human-readable description of what the command does and its usage.