pub struct DebugListCommandsResponse {
pub commands: Vec<CommandInfo>,
}Fields
commands: Vec<CommandInfo>Trait Implementations
Sourceimpl Clone for DebugListCommandsResponse
impl Clone for DebugListCommandsResponse
Sourcefn clone(&self) -> DebugListCommandsResponse
fn clone(&self) -> DebugListCommandsResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DebugListCommandsResponse
impl Debug for DebugListCommandsResponse
Sourceimpl<D: ResourceDialect> Decode<DebugListCommandsResponse, D> for DebugListCommandsResponse
impl<D: ResourceDialect> Decode<DebugListCommandsResponse, D> for DebugListCommandsResponse
Sourceimpl<D: ResourceDialect> Encode<DebugListCommandsResponse, D> for &DebugListCommandsResponse
impl<D: ResourceDialect> Encode<DebugListCommandsResponse, D> for &DebugListCommandsResponse
Sourceimpl<D: ResourceDialect, T0: Encode<Vector<CommandInfo, 64>, D>> Encode<DebugListCommandsResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<Vector<CommandInfo, 64>, D>> Encode<DebugListCommandsResponse, D> for (T0,)
impl Persistable for DebugListCommandsResponse
impl StructuralPartialEq for DebugListCommandsResponse
Sourceimpl TypeMarker for DebugListCommandsResponse
impl TypeMarker for DebugListCommandsResponse
Sourcetype Owned = DebugListCommandsResponse
type Owned = DebugListCommandsResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DebugListCommandsResponse
impl ValueTypeMarker for DebugListCommandsResponse
Sourcetype Borrowed<'a> = &'a DebugListCommandsResponse
type Borrowed<'a> = &'a DebugListCommandsResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DebugListCommandsResponse
impl RefUnwindSafe for DebugListCommandsResponse
impl Send for DebugListCommandsResponse
impl Sync for DebugListCommandsResponse
impl Unpin for DebugListCommandsResponse
impl UnsafeUnpin for DebugListCommandsResponse
impl UnwindSafe for DebugListCommandsResponse